# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from tests.utils import assert_matches_type
from deasy_client import Deasy, AsyncDeasy
from deasy_client.types import (
    TagResponse,
    TagListResponse,
    TagCreateResponse,
    TagUpsertResponse,
    TagGetDeleteStatsResponse,
)

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestTags:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip()
    @parametrize
    def test_method_create(self, client: Deasy) -> None:
        tag = client.tags.create(
            tag_data={
                "name": "name",
                "output_type": "output_type",
            },
        )
        assert_matches_type(TagCreateResponse, tag, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_method_create_with_all_params(self, client: Deasy) -> None:
        tag = client.tags.create(
            tag_data={
                "name": "name",
                "output_type": "output_type",
                "available_values": ["string"],
                "date_format": "date_format",
                "description": "description",
                "examples": [{"foo": "bar"}],
                "max_values": 0,
                "tag_id": "tag_id",
                "tuned": 0,
            },
        )
        assert_matches_type(TagCreateResponse, tag, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_create(self, client: Deasy) -> None:
        response = client.tags.with_raw_response.create(
            tag_data={
                "name": "name",
                "output_type": "output_type",
            },
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        tag = response.parse()
        assert_matches_type(TagCreateResponse, tag, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_create(self, client: Deasy) -> None:
        with client.tags.with_streaming_response.create(
            tag_data={
                "name": "name",
                "output_type": "output_type",
            },
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            tag = response.parse()
            assert_matches_type(TagCreateResponse, tag, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    def test_method_update(self, client: Deasy) -> None:
        tag = client.tags.update(
            tag_data={
                "name": "name",
                "output_type": "output_type",
            },
        )
        assert_matches_type(TagResponse, tag, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_method_update_with_all_params(self, client: Deasy) -> None:
        tag = client.tags.update(
            tag_data={
                "name": "name",
                "output_type": "output_type",
                "available_values": ["string"],
                "date_format": "date_format",
                "description": "description",
                "examples": [{"foo": "bar"}],
                "max_values": 0,
                "tag_id": "tag_id",
                "tuned": 0,
            },
        )
        assert_matches_type(TagResponse, tag, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_update(self, client: Deasy) -> None:
        response = client.tags.with_raw_response.update(
            tag_data={
                "name": "name",
                "output_type": "output_type",
            },
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        tag = response.parse()
        assert_matches_type(TagResponse, tag, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_update(self, client: Deasy) -> None:
        with client.tags.with_streaming_response.update(
            tag_data={
                "name": "name",
                "output_type": "output_type",
            },
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            tag = response.parse()
            assert_matches_type(TagResponse, tag, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    def test_method_list(self, client: Deasy) -> None:
        tag = client.tags.list()
        assert_matches_type(TagListResponse, tag, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_list(self, client: Deasy) -> None:
        response = client.tags.with_raw_response.list()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        tag = response.parse()
        assert_matches_type(TagListResponse, tag, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_list(self, client: Deasy) -> None:
        with client.tags.with_streaming_response.list() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            tag = response.parse()
            assert_matches_type(TagListResponse, tag, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    def test_method_delete(self, client: Deasy) -> None:
        tag = client.tags.delete(
            tag_name="tag_name",
        )
        assert_matches_type(TagResponse, tag, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_delete(self, client: Deasy) -> None:
        response = client.tags.with_raw_response.delete(
            tag_name="tag_name",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        tag = response.parse()
        assert_matches_type(TagResponse, tag, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_delete(self, client: Deasy) -> None:
        with client.tags.with_streaming_response.delete(
            tag_name="tag_name",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            tag = response.parse()
            assert_matches_type(TagResponse, tag, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    def test_method_get_delete_stats(self, client: Deasy) -> None:
        tag = client.tags.get_delete_stats(
            tag_name="tag_name",
        )
        assert_matches_type(TagGetDeleteStatsResponse, tag, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_get_delete_stats(self, client: Deasy) -> None:
        response = client.tags.with_raw_response.get_delete_stats(
            tag_name="tag_name",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        tag = response.parse()
        assert_matches_type(TagGetDeleteStatsResponse, tag, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_get_delete_stats(self, client: Deasy) -> None:
        with client.tags.with_streaming_response.get_delete_stats(
            tag_name="tag_name",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            tag = response.parse()
            assert_matches_type(TagGetDeleteStatsResponse, tag, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    def test_method_upsert(self, client: Deasy) -> None:
        tag = client.tags.upsert(
            tag_data={
                "name": "name",
                "output_type": "output_type",
            },
        )
        assert_matches_type(TagUpsertResponse, tag, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_method_upsert_with_all_params(self, client: Deasy) -> None:
        tag = client.tags.upsert(
            tag_data={
                "name": "name",
                "output_type": "output_type",
                "available_values": ["string"],
                "date_format": "date_format",
                "description": "description",
                "examples": [{"foo": "bar"}],
                "max_values": 0,
                "tag_id": "tag_id",
                "tuned": 0,
            },
        )
        assert_matches_type(TagUpsertResponse, tag, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_upsert(self, client: Deasy) -> None:
        response = client.tags.with_raw_response.upsert(
            tag_data={
                "name": "name",
                "output_type": "output_type",
            },
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        tag = response.parse()
        assert_matches_type(TagUpsertResponse, tag, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_upsert(self, client: Deasy) -> None:
        with client.tags.with_streaming_response.upsert(
            tag_data={
                "name": "name",
                "output_type": "output_type",
            },
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            tag = response.parse()
            assert_matches_type(TagUpsertResponse, tag, path=["response"])

        assert cast(Any, response.is_closed) is True


class TestAsyncTags:
    parametrize = pytest.mark.parametrize("async_client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip()
    @parametrize
    async def test_method_create(self, async_client: AsyncDeasy) -> None:
        tag = await async_client.tags.create(
            tag_data={
                "name": "name",
                "output_type": "output_type",
            },
        )
        assert_matches_type(TagCreateResponse, tag, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_method_create_with_all_params(self, async_client: AsyncDeasy) -> None:
        tag = await async_client.tags.create(
            tag_data={
                "name": "name",
                "output_type": "output_type",
                "available_values": ["string"],
                "date_format": "date_format",
                "description": "description",
                "examples": [{"foo": "bar"}],
                "max_values": 0,
                "tag_id": "tag_id",
                "tuned": 0,
            },
        )
        assert_matches_type(TagCreateResponse, tag, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_create(self, async_client: AsyncDeasy) -> None:
        response = await async_client.tags.with_raw_response.create(
            tag_data={
                "name": "name",
                "output_type": "output_type",
            },
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        tag = await response.parse()
        assert_matches_type(TagCreateResponse, tag, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_create(self, async_client: AsyncDeasy) -> None:
        async with async_client.tags.with_streaming_response.create(
            tag_data={
                "name": "name",
                "output_type": "output_type",
            },
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            tag = await response.parse()
            assert_matches_type(TagCreateResponse, tag, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    async def test_method_update(self, async_client: AsyncDeasy) -> None:
        tag = await async_client.tags.update(
            tag_data={
                "name": "name",
                "output_type": "output_type",
            },
        )
        assert_matches_type(TagResponse, tag, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_method_update_with_all_params(self, async_client: AsyncDeasy) -> None:
        tag = await async_client.tags.update(
            tag_data={
                "name": "name",
                "output_type": "output_type",
                "available_values": ["string"],
                "date_format": "date_format",
                "description": "description",
                "examples": [{"foo": "bar"}],
                "max_values": 0,
                "tag_id": "tag_id",
                "tuned": 0,
            },
        )
        assert_matches_type(TagResponse, tag, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_update(self, async_client: AsyncDeasy) -> None:
        response = await async_client.tags.with_raw_response.update(
            tag_data={
                "name": "name",
                "output_type": "output_type",
            },
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        tag = await response.parse()
        assert_matches_type(TagResponse, tag, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_update(self, async_client: AsyncDeasy) -> None:
        async with async_client.tags.with_streaming_response.update(
            tag_data={
                "name": "name",
                "output_type": "output_type",
            },
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            tag = await response.parse()
            assert_matches_type(TagResponse, tag, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    async def test_method_list(self, async_client: AsyncDeasy) -> None:
        tag = await async_client.tags.list()
        assert_matches_type(TagListResponse, tag, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_list(self, async_client: AsyncDeasy) -> None:
        response = await async_client.tags.with_raw_response.list()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        tag = await response.parse()
        assert_matches_type(TagListResponse, tag, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_list(self, async_client: AsyncDeasy) -> None:
        async with async_client.tags.with_streaming_response.list() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            tag = await response.parse()
            assert_matches_type(TagListResponse, tag, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    async def test_method_delete(self, async_client: AsyncDeasy) -> None:
        tag = await async_client.tags.delete(
            tag_name="tag_name",
        )
        assert_matches_type(TagResponse, tag, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_delete(self, async_client: AsyncDeasy) -> None:
        response = await async_client.tags.with_raw_response.delete(
            tag_name="tag_name",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        tag = await response.parse()
        assert_matches_type(TagResponse, tag, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_delete(self, async_client: AsyncDeasy) -> None:
        async with async_client.tags.with_streaming_response.delete(
            tag_name="tag_name",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            tag = await response.parse()
            assert_matches_type(TagResponse, tag, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    async def test_method_get_delete_stats(self, async_client: AsyncDeasy) -> None:
        tag = await async_client.tags.get_delete_stats(
            tag_name="tag_name",
        )
        assert_matches_type(TagGetDeleteStatsResponse, tag, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_get_delete_stats(self, async_client: AsyncDeasy) -> None:
        response = await async_client.tags.with_raw_response.get_delete_stats(
            tag_name="tag_name",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        tag = await response.parse()
        assert_matches_type(TagGetDeleteStatsResponse, tag, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_get_delete_stats(self, async_client: AsyncDeasy) -> None:
        async with async_client.tags.with_streaming_response.get_delete_stats(
            tag_name="tag_name",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            tag = await response.parse()
            assert_matches_type(TagGetDeleteStatsResponse, tag, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    async def test_method_upsert(self, async_client: AsyncDeasy) -> None:
        tag = await async_client.tags.upsert(
            tag_data={
                "name": "name",
                "output_type": "output_type",
            },
        )
        assert_matches_type(TagUpsertResponse, tag, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_method_upsert_with_all_params(self, async_client: AsyncDeasy) -> None:
        tag = await async_client.tags.upsert(
            tag_data={
                "name": "name",
                "output_type": "output_type",
                "available_values": ["string"],
                "date_format": "date_format",
                "description": "description",
                "examples": [{"foo": "bar"}],
                "max_values": 0,
                "tag_id": "tag_id",
                "tuned": 0,
            },
        )
        assert_matches_type(TagUpsertResponse, tag, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_upsert(self, async_client: AsyncDeasy) -> None:
        response = await async_client.tags.with_raw_response.upsert(
            tag_data={
                "name": "name",
                "output_type": "output_type",
            },
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        tag = await response.parse()
        assert_matches_type(TagUpsertResponse, tag, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_upsert(self, async_client: AsyncDeasy) -> None:
        async with async_client.tags.with_streaming_response.upsert(
            tag_data={
                "name": "name",
                "output_type": "output_type",
            },
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            tag = await response.parse()
            assert_matches_type(TagUpsertResponse, tag, path=["response"])

        assert cast(Any, response.is_closed) is True



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Dict, List, Union, Iterable, Optional
from datetime import datetime
from typing_extensions import Required, Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = ["ClassifyBulkClassifyParams", "TagDatas"]


class ClassifyBulkClassifyParams(TypedDict, total=False):
    vdb_profile_name: Required[str]

    conditions: Optional["ConditionInputParam"]

    dataslice_id: Optional[str]

    hierarchy_data: Optional[Dict[str, object]]

    hierarchy_name: Optional[str]

    job_id: Optional[str]

    llm_profile_name: Optional[str]

    overwrite: bool

    tag_datas: Optional[Dict[str, TagDatas]]

    tag_names: Optional[List[str]]

    total_data_sets: Optional[int]


class TagDatas(TypedDict, total=False):
    description: Required[str]

    name: Required[str]

    output_type: Required[str]

    available_values: Optional[List[str]]

    created_at: Annotated[Union[str, datetime, None], PropertyInfo(format="iso8601")]

    date_format: Optional[str]

    examples: Optional[List[Union[str, Dict[str, object]]]]

    max_values: Annotated[Union[int, str, Iterable[object], None], PropertyInfo(alias="maxValues")]

    neg_examples: Optional[List[str]]

    retry_feedback: Optional[Dict[str, object]]

    tag_id: Optional[str]

    tuned: Optional[int]

    updated_at: Annotated[Union[str, datetime, None], PropertyInfo(format="iso8601")]

    username: Optional[str]


from .condition_input_param import ConditionInputParam



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Dict, List, Optional

from .._models import BaseModel
from .deasy_tag import DeasyTag

__all__ = ["SuggestSchemaCreateResponse", "CreatedTag"]


class CreatedTag(BaseModel):
    deasy_tag: DeasyTag

    new_available_values: List[str]


class SuggestSchemaCreateResponse(BaseModel):
    suggestion: Dict[str, object]

    created_tags: Optional[List[CreatedTag]] = None

    message: Optional[str] = None

    status_code: Optional[int] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .deasy_tag import DeasyTag as DeasyTag
from .tag_response import TagResponse as TagResponse
from .openai_config import OpenAIConfig as OpenAIConfig
from .condition_output import ConditionOutput as ConditionOutput
from .graph_list_params import GraphListParams as GraphListParams
from .tag_create_params import TagCreateParams as TagCreateParams
from .tag_delete_params import TagDeleteParams as TagDeleteParams
from .tag_list_response import TagListResponse as TagListResponse
from .tag_update_params import TagUpdateParams as TagUpdateParams
from .tag_upsert_params import TagUpsertParams as TagUpsertParams
from .connector_response import ConnectorResponse as ConnectorResponse
from .list_vdb_connector import ListVdbConnector as ListVdbConnector
from .graph_create_params import GraphCreateParams as GraphCreateParams
from .graph_delete_params import GraphDeleteParams as GraphDeleteParams
from .graph_list_response import GraphListResponse as GraphListResponse
from .graph_update_params import GraphUpdateParams as GraphUpdateParams
from .graph_upsert_params import GraphUpsertParams as GraphUpsertParams
from .openai_config_param import OpenAIConfigParam as OpenAIConfigParam
from .s3_connector_config import S3ConnectorConfig as S3ConnectorConfig
from .tag_create_response import TagCreateResponse as TagCreateResponse
from .tag_upsert_response import TagUpsertResponse as TagUpsertResponse
from .metadata_list_params import MetadataListParams as MetadataListParams
from .condition_input_param import ConditionInputParam as ConditionInputParam
from .psql_connector_config import PsqlConnectorConfig as PsqlConnectorConfig
from .metadata_delete_params import MetadataDeleteParams as MetadataDeleteParams
from .metadata_list_response import MetadataListResponse as MetadataListResponse
from .metadata_upsert_params import MetadataUpsertParams as MetadataUpsertParams
from .dataslice_create_params import DatasliceCreateParams as DatasliceCreateParams
from .dataslice_delete_params import DatasliceDeleteParams as DatasliceDeleteParams
from .dataslice_list_response import DatasliceListResponse as DatasliceListResponse
from .qdrant_connector_config import QdrantConnectorConfig as QdrantConnectorConfig
from .graph_operation_response import GraphOperationResponse as GraphOperationResponse
from .metadata_delete_response import MetadataDeleteResponse as MetadataDeleteResponse
from .metadata_upsert_response import MetadataUpsertResponse as MetadataUpsertResponse
from .dataslice_create_response import DatasliceCreateResponse as DatasliceCreateResponse
from .dataslice_delete_response import DatasliceDeleteResponse as DatasliceDeleteResponse
from .s3_connector_config_param import S3ConnectorConfigParam as S3ConnectorConfigParam
from .dataslice_get_files_params import DatasliceGetFilesParams as DatasliceGetFilesParams
from .prepare_data_create_params import PrepareDataCreateParams as PrepareDataCreateParams
from .llm_connector_create_params import LlmConnectorCreateParams as LlmConnectorCreateParams
from .llm_connector_delete_params import LlmConnectorDeleteParams as LlmConnectorDeleteParams
from .llm_connector_list_response import LlmConnectorListResponse as LlmConnectorListResponse
from .llm_connector_update_params import LlmConnectorUpdateParams as LlmConnectorUpdateParams
from .psql_connector_config_param import PsqlConnectorConfigParam as PsqlConnectorConfigParam
from .sharepoint_connector_config import SharepointConnectorConfig as SharepointConnectorConfig
from .tag_get_delete_stats_params import TagGetDeleteStatsParams as TagGetDeleteStatsParams
from .vdb_connector_create_params import VdbConnectorCreateParams as VdbConnectorCreateParams
from .vdb_connector_delete_params import VdbConnectorDeleteParams as VdbConnectorDeleteParams
from .vdb_connector_update_params import VdbConnectorUpdateParams as VdbConnectorUpdateParams
from .dataslice_get_files_response import DatasliceGetFilesResponse as DatasliceGetFilesResponse
from .dataslice_get_metrics_params import DatasliceGetMetricsParams as DatasliceGetMetricsParams
from .prepare_data_create_response import PrepareDataCreateResponse as PrepareDataCreateResponse
from .suggest_schema_create_params import SuggestSchemaCreateParams as SuggestSchemaCreateParams
from .classify_bulk_classify_params import ClassifyBulkClassifyParams as ClassifyBulkClassifyParams
from .qdrant_connector_config_param import QdrantConnectorConfigParam as QdrantConnectorConfigParam
from .tag_get_delete_stats_response import TagGetDeleteStatsResponse as TagGetDeleteStatsResponse
from .classify_classify_files_params import ClassifyClassifyFilesParams as ClassifyClassifyFilesParams
from .dataslice_get_metrics_response import DatasliceGetMetricsResponse as DatasliceGetMetricsResponse
from .metadata_list_paginated_params import MetadataListPaginatedParams as MetadataListPaginatedParams
from .suggest_schema_create_response import SuggestSchemaCreateResponse as SuggestSchemaCreateResponse
from .classify_bulk_classify_response import ClassifyBulkClassifyResponse as ClassifyBulkClassifyResponse
from .dataslice_get_file_count_params import DatasliceGetFileCountParams as DatasliceGetFileCountParams
from .classify_classify_files_response import ClassifyClassifyFilesResponse as ClassifyClassifyFilesResponse
from .metadata_list_paginated_response import MetadataListPaginatedResponse as MetadataListPaginatedResponse
from .dataslice_get_file_count_response import DatasliceGetFileCountResponse as DatasliceGetFileCountResponse
from .sharepoint_connector_config_param import SharepointConnectorConfigParam as SharepointConnectorConfigParam
from .suggest_description_create_params import SuggestDescriptionCreateParams as SuggestDescriptionCreateParams
from .suggest_description_create_response import SuggestDescriptionCreateResponse as SuggestDescriptionCreateResponse
from .vdb_connector_get_delete_stats_params import VdbConnectorGetDeleteStatsParams as VdbConnectorGetDeleteStatsParams
from .vdb_connector_get_delete_stats_response import (
    VdbConnectorGetDeleteStatsResponse as VdbConnectorGetDeleteStatsResponse,
)
from .dataslice_get_tag_vdb_distribution_params import (
    DatasliceGetTagVdbDistributionParams as DatasliceGetTagVdbDistributionParams,
)
from .dataslice_get_tag_vdb_distribution_response import (
    DatasliceGetTagVdbDistributionResponse as DatasliceGetTagVdbDistributionResponse,
)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List

from .._models import BaseModel

__all__ = ["TagGetDeleteStatsResponse"]


class TagGetDeleteStatsResponse(BaseModel):
    dataslices_with_tag: List[str]

    file_count_with_tag: int

    graphs_with_tag: List[str]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional
from typing_extensions import Literal

from .._models import BaseModel

__all__ = ["QdrantConnectorConfig", "IndexInfo"]


class IndexInfo(BaseModel):
    total_indexes_found: int


class QdrantConnectorConfig(BaseModel):
    api_key: str

    collection_name: str

    name: str

    url: str

    filename_key: Optional[str] = None

    index_info: Optional[IndexInfo] = None

    text_key: Optional[str] = None

    type: Optional[Literal["QdrantVectorDBManager"]] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Dict, List, Optional

from .._models import BaseModel

__all__ = [
    "MetadataListPaginatedResponse",
    "MetadataMetadataItem",
    "MetadataMetadataItemChunkLevel",
    "MetadataMetadataItemFileLevel",
]


class MetadataMetadataItemChunkLevel(BaseModel):
    values: List[str]

    evidence: Optional[str] = None


class MetadataMetadataItemFileLevel(BaseModel):
    values: List[str]

    evidence: Optional[str] = None


class MetadataMetadataItem(BaseModel):
    chunk_level: Optional[Dict[str, Optional[MetadataMetadataItemChunkLevel]]] = None

    file_level: Optional[MetadataMetadataItemFileLevel] = None


class MetadataListPaginatedResponse(BaseModel):
    metadata: Dict[str, Dict[str, MetadataMetadataItem]]

    next_offset: Optional[int] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Dict, List, Optional

import httpx

from ..types import (
    graph_list_params,
    graph_create_params,
    graph_delete_params,
    graph_update_params,
    graph_upsert_params,
)
from .._types import NOT_GIVEN, Body, Query, Headers, NotGiven
from .._utils import (
    maybe_transform,
    async_maybe_transform,
)
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options
from ..types.graph_list_response import GraphListResponse
from ..types.graph_operation_response import GraphOperationResponse

__all__ = ["GraphResource", "AsyncGraphResource"]


class GraphResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> GraphResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/Deasie-internal/deasy-python#accessing-raw-response-data-eg-headers
        """
        return GraphResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> GraphResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/Deasie-internal/deasy-python#with_streaming_response
        """
        return GraphResourceWithStreamingResponse(self)

    def create(
        self,
        *,
        graph_name: str,
        graph_data: Optional[Dict[str, object]] | NotGiven = NOT_GIVEN,
        graph_description: Optional[str] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> GraphOperationResponse:
        """
        Create a new graph.

        Attributes:

            graph_name: The name of the graph to create.
            graph_description: The description of the graph to create.
            graph_data: The data of the graph to create.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/graph/create",
            body=maybe_transform(
                {
                    "graph_name": graph_name,
                    "graph_data": graph_data,
                    "graph_description": graph_description,
                },
                graph_create_params.GraphCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=GraphOperationResponse,
        )

    def update(
        self,
        *,
        graph_name: str,
        graph_data: Optional[Dict[str, object]] | NotGiven = NOT_GIVEN,
        graph_description: Optional[str] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> GraphOperationResponse:
        """
        Update a graph in the database.

        Attributes:

            graph_name: The name of the graph to update.
            graph_description: The description of the graph to update.
            graph_data: The data of the graph to update.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/graph/update",
            body=maybe_transform(
                {
                    "graph_name": graph_name,
                    "graph_data": graph_data,
                    "graph_description": graph_description,
                },
                graph_update_params.GraphUpdateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=GraphOperationResponse,
        )

    def list(
        self,
        *,
        graph_names: Optional[List[str]] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> GraphListResponse:
        """
        List all graphs for the authenticated user.

        Attributes:

            graph_names: The names of the graphs to retrieve.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/graph/list",
            body=maybe_transform({"graph_names": graph_names}, graph_list_params.GraphListParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=GraphListResponse,
        )

    def delete(
        self,
        *,
        graph_name: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> GraphOperationResponse:
        """
        Delete a graph by name.

        Attributes:

            graph_name: The name of the graph to delete.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._delete(
            "/graph/delete",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform({"graph_name": graph_name}, graph_delete_params.GraphDeleteParams),
            ),
            cast_to=GraphOperationResponse,
        )

    def upsert(
        self,
        *,
        graph_name: str,
        graph_data: Optional[Dict[str, object]] | NotGiven = NOT_GIVEN,
        graph_description: Optional[str] | NotGiven = NOT_GIVEN,
        new_graph_name: Optional[str] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> GraphOperationResponse:
        """
        Upsert a graph in the database.

        Attributes:

            graph_name: The stored name of the graph to upsert.
            new_graph_name: The new name of the graph to upsert.
            graph_description: The description of the graph to upsert.
            graph_data: The data of the graph to upsert.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/graph/upsert",
            body=maybe_transform(
                {
                    "graph_name": graph_name,
                    "graph_data": graph_data,
                    "graph_description": graph_description,
                    "new_graph_name": new_graph_name,
                },
                graph_upsert_params.GraphUpsertParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=GraphOperationResponse,
        )


class AsyncGraphResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncGraphResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/Deasie-internal/deasy-python#accessing-raw-response-data-eg-headers
        """
        return AsyncGraphResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncGraphResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/Deasie-internal/deasy-python#with_streaming_response
        """
        return AsyncGraphResourceWithStreamingResponse(self)

    async def create(
        self,
        *,
        graph_name: str,
        graph_data: Optional[Dict[str, object]] | NotGiven = NOT_GIVEN,
        graph_description: Optional[str] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> GraphOperationResponse:
        """
        Create a new graph.

        Attributes:

            graph_name: The name of the graph to create.
            graph_description: The description of the graph to create.
            graph_data: The data of the graph to create.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/graph/create",
            body=await async_maybe_transform(
                {
                    "graph_name": graph_name,
                    "graph_data": graph_data,
                    "graph_description": graph_description,
                },
                graph_create_params.GraphCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=GraphOperationResponse,
        )

    async def update(
        self,
        *,
        graph_name: str,
        graph_data: Optional[Dict[str, object]] | NotGiven = NOT_GIVEN,
        graph_description: Optional[str] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> GraphOperationResponse:
        """
        Update a graph in the database.

        Attributes:

            graph_name: The name of the graph to update.
            graph_description: The description of the graph to update.
            graph_data: The data of the graph to update.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/graph/update",
            body=await async_maybe_transform(
                {
                    "graph_name": graph_name,
                    "graph_data": graph_data,
                    "graph_description": graph_description,
                },
                graph_update_params.GraphUpdateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=GraphOperationResponse,
        )

    async def list(
        self,
        *,
        graph_names: Optional[List[str]] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> GraphListResponse:
        """
        List all graphs for the authenticated user.

        Attributes:

            graph_names: The names of the graphs to retrieve.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/graph/list",
            body=await async_maybe_transform({"graph_names": graph_names}, graph_list_params.GraphListParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=GraphListResponse,
        )

    async def delete(
        self,
        *,
        graph_name: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> GraphOperationResponse:
        """
        Delete a graph by name.

        Attributes:

            graph_name: The name of the graph to delete.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._delete(
            "/graph/delete",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform({"graph_name": graph_name}, graph_delete_params.GraphDeleteParams),
            ),
            cast_to=GraphOperationResponse,
        )

    async def upsert(
        self,
        *,
        graph_name: str,
        graph_data: Optional[Dict[str, object]] | NotGiven = NOT_GIVEN,
        graph_description: Optional[str] | NotGiven = NOT_GIVEN,
        new_graph_name: Optional[str] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> GraphOperationResponse:
        """
        Upsert a graph in the database.

        Attributes:

            graph_name: The stored name of the graph to upsert.
            new_graph_name: The new name of the graph to upsert.
            graph_description: The description of the graph to upsert.
            graph_data: The data of the graph to upsert.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/graph/upsert",
            body=await async_maybe_transform(
                {
                    "graph_name": graph_name,
                    "graph_data": graph_data,
                    "graph_description": graph_description,
                    "new_graph_name": new_graph_name,
                },
                graph_upsert_params.GraphUpsertParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=GraphOperationResponse,
        )


class GraphResourceWithRawResponse:
    def __init__(self, graph: GraphResource) -> None:
        self._graph = graph

        self.create = to_raw_response_wrapper(
            graph.create,
        )
        self.update = to_raw_response_wrapper(
            graph.update,
        )
        self.list = to_raw_response_wrapper(
            graph.list,
        )
        self.delete = to_raw_response_wrapper(
            graph.delete,
        )
        self.upsert = to_raw_response_wrapper(
            graph.upsert,
        )


class AsyncGraphResourceWithRawResponse:
    def __init__(self, graph: AsyncGraphResource) -> None:
        self._graph = graph

        self.create = async_to_raw_response_wrapper(
            graph.create,
        )
        self.update = async_to_raw_response_wrapper(
            graph.update,
        )
        self.list = async_to_raw_response_wrapper(
            graph.list,
        )
        self.delete = async_to_raw_response_wrapper(
            graph.delete,
        )
        self.upsert = async_to_raw_response_wrapper(
            graph.upsert,
        )


class GraphResourceWithStreamingResponse:
    def __init__(self, graph: GraphResource) -> None:
        self._graph = graph

        self.create = to_streamed_response_wrapper(
            graph.create,
        )
        self.update = to_streamed_response_wrapper(
            graph.update,
        )
        self.list = to_streamed_response_wrapper(
            graph.list,
        )
        self.delete = to_streamed_response_wrapper(
            graph.delete,
        )
        self.upsert = to_streamed_response_wrapper(
            graph.upsert,
        )


class AsyncGraphResourceWithStreamingResponse:
    def __init__(self, graph: AsyncGraphResource) -> None:
        self._graph = graph

        self.create = async_to_streamed_response_wrapper(
            graph.create,
        )
        self.update = async_to_streamed_response_wrapper(
            graph.update,
        )
        self.list = async_to_streamed_response_wrapper(
            graph.list,
        )
        self.delete = async_to_streamed_response_wrapper(
            graph.delete,
        )
        self.upsert = async_to_streamed_response_wrapper(
            graph.upsert,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Dict, Union
from typing_extensions import TypeAlias

from .._models import BaseModel
from .s3_connector_config import S3ConnectorConfig
from .psql_connector_config import PsqlConnectorConfig
from .qdrant_connector_config import QdrantConnectorConfig
from .sharepoint_connector_config import SharepointConnectorConfig

__all__ = ["ListVdbConnector", "Connectors"]

Connectors: TypeAlias = Union[PsqlConnectorConfig, QdrantConnectorConfig, S3ConnectorConfig, SharepointConnectorConfig]


class ListVdbConnector(BaseModel):
    connectors: Dict[str, Connectors]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Dict, List, Union, Iterable, Optional
from datetime import datetime
from typing_extensions import Literal, Required, Annotated, TypedDict

from ..._utils import PropertyInfo

__all__ = ["DeasySelectQueryParams", "TagSchema"]


class DeasySelectQueryParams(TypedDict, total=False):
    query: Required[str]

    vdb_profile_name: Required[str]

    columns: Optional[List[Literal["id", "filename", "text", "tags", "page_num", "dense", "point_id"]]]

    data_description: Optional[str]

    filter_type: Optional[Literal["deasy", "sql"]]

    max_search_reduction: Optional[float]

    min_search_reduction: Optional[float]

    return_type: Optional[Literal["results", "condition", "both"]]

    tag_level: Optional[Literal["file", "chunk", "both"]]

    tag_names: Optional[List[str]]

    tag_schemas: Optional[Iterable[TagSchema]]


class TagSchema(TypedDict, total=False):
    description: Required[str]

    name: Required[str]

    output_type: Required[str]

    available_values: Optional[List[str]]

    created_at: Annotated[Union[str, datetime, None], PropertyInfo(format="iso8601")]

    date_format: Optional[str]

    examples: Optional[List[Union[str, Dict[str, object]]]]

    max_values: Annotated[Union[int, str, Iterable[object], None], PropertyInfo(alias="maxValues")]

    neg_examples: Optional[List[str]]

    retry_feedback: Optional[Dict[str, object]]

    tag_id: Optional[str]

    tuned: Optional[int]

    updated_at: Annotated[Union[str, datetime, None], PropertyInfo(format="iso8601")]

    username: Optional[str]
